local target_nearest_real_enemy = {}
target_nearest_real_enemy.player_list = {}

function target_nearest_real_enemy.is_enemy(id)

   local name = GetPlayerName(id) or ""
   local guild = GetGuildTag(id) or ""

   if GetFriendlyStatus(id) then

      -- guild members are friends
      if guild == GetGuildAcronym() then
	 return false
      end

      -- group members are friends
      if IsGroupMember(GetCharacterIDByName(name)) then
	 return false
      end

      return true
   else
      return false
   end
end

function target_nearest_real_enemy.next_target()

   target_nearest_real_enemy.player_list = {} -- clear list
   ForEachPlayer(function (id)
		    if id ~= GetCharacterID() or id == 0 then
		       table.insert(
			  target_nearest_real_enemy.player_list, 
			  {id=id, distance=GetPlayerDistance(id) or 9999}
		       )
		    end
		 end)
   table.sort(target_nearest_real_enemy.player_list, function(a,b) return (a.distance < b.distance) end)

   for _,player in pairs(target_nearest_real_enemy.player_list) do 
      if target_nearest_real_enemy.is_enemy(player.id) then
	 -- set target and exit
	 radar.SetRadarSelection(GetPlayerNodeID(player.id), GetPrimaryShipIDOfPlayer(player.id))
	 return
      end
   end

   -- no enemies found -> deselect target
   gkinterface.GKProcessCommand("RadarNone")

end

function target_nearest_real_enemy.unload()
   -- remove RadarNextNearestEnemy bind overrides

   gkinterface.UnbindCommand("target_nearest_real_enemy")

   for _,key in pairs(target_nearest_real_enemy.old_binds) do
      gkinterface.BindCommand(gkinterface.GetInputCodeByName(key), "RadarNextNearestEnemy")
   end
end

function target_nearest_real_enemy.load()
   -- override RadarNextNearestEnemy bind

   target_nearest_real_enemy.old_binds = gkinterface.GetBindsForCommand("RadarNextNearestEnemy")

   RegisterUserCommand("RadarNextNearestEnemyEx", target_nearest_real_enemy.next_target)
   gkinterface.GKProcessCommand('alias target_nearest_real_enemy RadarNextNearestEnemyEx')

   gkinterface.UnbindCommand("RadarNextNearestEnemy")
   for _,key in pairs(target_nearest_real_enemy.old_binds) do
      gkinterface.BindCommand(gkinterface.GetInputCodeByName(key), "target_nearest_real_enemy")
   end
end


function target_nearest_real_enemy:OnEvent(event, data)
   if event == "UNLOAD_INTERFACE" then
      target_nearest_real_enemy.unload()
      return true
   end

   if event == "PLAYER_ENTERED_GAME" then
      target_nearest_real_enemy.load()
   end
end
RegisterEvent(target_nearest_real_enemy, "PLAYER_ENTERED_GAME")
RegisterEvent(target_nearest_real_enemy, "UNLOAD_INTERFACE")

